#!/bin/sh

# chkconfig: 2345 95 5
# description: Driver and daemon for Sealevel SeaLink 480x devices
#
# Initialization script configuration
#
MODULE_REGEXP="SeaLink\b|SeaLink_Vi\b"
DRIVER_NAME="SeaLink driver"
DRIVER_FN=SeaLink
DAEMON=/sbin/sealinkd

ACTION="start"
#ACTION="stop"
#ACTION="restart"

#
# Handle System V init conventions...
#
case $ACTION in
start)
	action="start";
	;;
stop)
	action="stop";
	;;
restart)
        action="restart";
        ;;
*)
	action="start";
esac

if test $action  = stop -o $action = restart; then
	module=`egrep $MODULE_REGEXP /proc/modules | awk '{print $1}'`
	if test -z "$module" ; then 
		echo "The $DRIVER_NAME is not loaded."
		exit 0
	fi
	echo -n "SeaLink: killing sealinkd..."
	if test -f /var/run/sealinkd.pid ; then
	    pid=`head -1 /var/run/sealinkd.pid`
	    kill $pid
	    if [ -x /bin/usleep ]; then
		/bin/usleep 100000
	    fi
	    rm -f /var/run/sealinkd.pid
	    sleep 1
	fi
	echo "done"
	echo -n "SeaLink: unloading the driver..."
	if /sbin/rmmod $module ; then :; else 
		echo "The $DRIVER_NAME could NOT be unloaded."
		exit 1;
	fi
	echo "done"
	rm -f /var/lock/subsys/sealink
        if test $action = stop; then
		exit 0
        	fi
fi

#
# Do sanity checks before we start..
#
if test ! -f /etc/sealink.conf ; then
    echo "Could not find /etc/sealink.conf!  To generate this file, run sealinkcfg."
    exit 1
fi

if test ! -x $DAEMON ; then
    echo "SeaLink daemon not installed!  Should be in $DAEMON"
    exit 1
fi

if test -f /var/run/sealinkd.pid ; then
    pid=`head -1 /var/run/sealinkd.pid`
    if kill -0 $pid >/dev/null ; then
       echo "SeaLink daemon already running"
       exit 1
    fi
fi

if test -d /var/lock/subsys ; then
  LOCKFILE=/var/lock/subsys/sealink
elif test -d /var/lock ; then
  LOCKFILE=/var/lock/sealink
elif test -d /tmp ; then
  LOCKFILE=/tmp/sealink.lock
else
  echo "Sorry, can't find anyplace for lock file"
  exit 1
fi

#
# run the sealinkcfg utility in automatic mode to update any IPs of
# installed devices that may have changed
#

if [ -f /usr/sbin/sealinkcfg ]; then
	echo -n "SeaLink: updating device configuration..."
	/usr/sbin/sealinkcfg -a
	echo "done"
fi

#
# If we get this far, we're supposed to load the driver.
#

if grep $MODULE_REGEXP /proc/modules > /dev/null ; then
	echo "The $DRIVER_NAME is already loaded!"
	exit 0
fi

DIRS="/lib/modules/`uname -r`/misc /lib/modules /usr/lib/modules ."
PATH=/bin:/sbin:/usr/bin

for i in $DIRS
do
	if test -z "$DRIVER_MODULE" -a -f $i/$DRIVER_FN.o ; then
		DRIVER_MODULE=$i/$DRIVER_FN.o
	fi
	if test -z "$MOD_DRIVER_MODULE" -a -f $i/$DRIVER_FN"_Vi.o" ; then
		MOD_DRIVER_MODULE=$i/$DRIVER_FN"_Vi.o"
	fi
done

if test -z "$DRIVER_MODULE" ; then
	DRIVER_MODULE=$MOD_DRIVER_MODULE
fi

if test -z "$DRIVER_MODULE" ; then
	echo "Couldn't find the $DRIVER_NAME loadable kernel module!"
	exit 1
fi

if [ -f /tmp/sealink.map ] ; then
    mv /tmp/sealink.map /tmp/sealink.map.old
fi

echo -n "SeaLink: loading the driver..."
if insmod -f $DRIVER_MODULE $ROCKET_ARG > /tmp/sealink.map 2> /tmp/driver.$$; then :; else
	echo "Couldn't load $DRIVER_NAME"
	echo "See error logs in /tmp/driver.$$"
	exit 1
fi

echo "done"

/bin/rm -f /tmp/driver.$$

echo -n "SeaLink: starting sealinkd..."
$DAEMON
echo "done"

touch $LOCKFILE

exit 0
